## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software.
## This file is part of the Image Processing Toolbox for Octave
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## struct    Create a structure from a sequence of field names and the 
##           corresponding initial values.
##
##           struct_val = struct(...)
##           ...        - fieldname, value - pairs of field names and values.
##                        Field names should be strings.
##           struct_val - a struct with fields of the given names and values.

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 19.12.98.

function struct_val = struct(...)

  if (rem(nargin, 2) ~= 0)
    error('struct: Field and value input arguments must come in pairs (nargin is odd).');
  endif

  va_start ();
  current_arg_num = 1;
  while (current_arg_num < nargin)
    field_name  = va_arg();
    field_value = va_arg();
    if (~isstr(field_name))
      error(sprintf('struct: Field names must be strings (argument #%d).', current_arg_num));
    endif
                    
    create_struct_command = sprintf('struct_val.%s = field_value;', field_name);
    eval(create_struct_command);
    current_arg_num += 2;
  endwhile

endfunction
