## Copyright (C) 1998 Ariel Tankus
## 
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## repmat    Replicate a matrix for a given number of times.
##           into a block matrix, where each block is the
##           original matrix. 
##    
##           r = repmat(mat, m, n)
##           mat  - a given matrix.
##           m, n - #block in rows and # blocks in cols in the
##                  replicated matrix.
##           r    - block matrix with m x n blocks, each is a
##                  copy of mat.
##
##           See also: reshape .
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 3.6.98.
## Version: 1.0

function r = repmat(mat, m, n)

  if ((nargin < 3) & (prod(size(m)) == 1)), n = m; end

  [s1, s2] = size(mat);
  r = zeros(m * s1, n * s2);

  for i=1:m
    for j=1:n
      r(((i-1)*s1+1):(i*s1), ((j-1)*s2+1):(j*s2)) = mat;
    end
  end

endfunction
