## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software.
## This file is part of the Image Processing Toolbox for Octave
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## imresize    Scale an image - either zoom in or zoom out.
##
##             scaledIm = imresize(im, scaleFactor, isPpm)
##             im          - image to be scaled.
##             scaleFactor - factor by which both image dimensions are scaled.
##             isPpm       - 0 - if given format is PGM,
##                           1 - if given format is PPM.
##                           The image `im' should be given in the appropriate
##                           format.
##
##             Note: This function depends on: `pnmscale', which is part of
##                   netpbm.
##
##             See also: writepgm, writeppm, writepnm, readpnm.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 22.9.98.
## Version: 1.0

function scaledIm = imresize(im, scaleFactor, isPpm)

  if (nargin < 3)
    isPpm = false;
  end

  PNM_SCALE = 'pnmscale';
  [in, out, pid] = popen2(PNM_SCALE, mat2str(scaleFactor));

  writepnm(in, im, isPpm);
  fclose(in);
  [scaledIm, isPpm] = readpnm(out);

endfunction
