## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software.
## This file is part of the Image Processing Toolbox for Octave
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## writepgm  Write an image into a file in PGM format.  Image values
##           are scaled to [0,255].
##
##           writepgm(fname, im)
##           fname - file name.
##           im    - image to write into the file.
##
##           writepgm(fid, im)
##           fid - file ID. File should be opened before calling 
##                 writepgm, and closed afterwards.
##           im  - image to write into file.
##
##           See also: writeppm, writepnm, readpnm, readimagefile.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 11.5.98.
## Version: 1.0

function writepgm(fname, im)

  maxScaledIm = 255;

  inputAsName = isstr(fname);    # is input given as filename or file ID?
  if (inputAsName)
    fid = fopen(fname, 'w');
    if (fid == -1)
      error(['Unable to open file: ', fname]);
      return;
    end
  else
    fid = fname;
  end

  minIm = min(min(im));
  maxIm = max(max(im));
  scaledIm = (im - minIm) ./ (maxIm - minIm) .* maxScaledIm;

  ## write header
  fprintf(fid, 'P5\n%d %d\n%d\n', size(im,2), size(im,1), maxScaledIm);

  ## write data
  count = fwrite(fid, scaledIm', 'uchar');
  if (count ~= prod(size(im)))
    error('Write failure. Unable to write all elements.');
  end

  if (inputAsName)
    fclose(fid);
  end

endfunction
