## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software.
## This file is part of the Image Processing Toolbox for Octave
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## writeppm  Write an image into a file in PPM format.
##
##       writeppm(fname, im)
##       fname - File name.
##       im    - image to write into file.
##
##       writeppm(fid, im)
##       fid - File ID. File should be opened before calling 
##             writeppm, and be closed afterwards.
##       im  - image to write into file.
##
##       See also: writepgm, writepnm, readpnm.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 11.5.98.
## Version: 1.0

function writeppm(fname, im)

  inputAsName = isstr(fname);    # is input given as filename or file ID?
  if (inputAsName)
    fid = fopen(fname, 'w');
    if (fid == -1)
      error(['Unable to open file: ', fname]);
      return;
    end
  else
    fid = fname;
  end

  scaledIm = scl(im, 0, 255);
  fprintf(fid, 'P6\n%d %d\n%d\n', size(scaledIm,2)/3, size(scaledIm,1), ...
          max(max(scaledIm)));

  keyboard
  count = fwrite(fid, scaledIm', 'uchar');
  if (count ~= prod(size(scaledIm)))
    error('Write failure. Unable to write all elements.');
  end

  if (inputAsName)
    fclose(fid);
  end

endfunction
