## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software.
## This file is part of the Image Processing Toolbox for Octave
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## getNonComment	Read the next token from a file, and remove any comment.
##               A comment is defined from the comment-char to the end-of-line.
##
##               currentToken = getNonComment(fid, commentChar)
##               fid          - file ID.
##               commentChar  - character which begins a comment.
##               currentToken - the token without the comment.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 7.8.98.
## Version: 1.0

function currentToken = getNonComment(fid, commentChar)

  if (nargin < 2)
    commentChar = '#';
  end

  newlineChar = setstr(10);
  currentToken = '';

  while (length(currentToken) == 0)

    currentToken = fscanf(fid, ' %s', "C");

    ## delete comment
    commentStart = index(currentToken, commentChar);
    if (commentStart ~= 0)

      ## comment found
      currentToken = currentToken(1:(commentStart-1));

      ## skip to end-of-line
      ch = fscanf(fid, '%c', "C");
      while (ch ~= newlineChar)
        ch = fscanf(fid, '%c', "C");
      end

    end

  end

endfunction
