% cofactor    Calculate the cofactor of a matrix.
%             The cofactor of a square matrix is defined as follows:
%
%             Let A=(a_ij) be a matrix of order n.  We denote by M_ij the
%             square sub-matrix of order (n-1) which is A where we omit
%             row i and column j.  The cofactor of element a_ij is
%             defined by:
%
%             A_ij = ((-1)^(i+j)) * det(M_ij)
%
%             cof_mat = cofactor(A)
%             A       - nxn - square matrix.
%             cof_mat - nxn - cofactor matrix of A.
%
%             Reference: Theory and Problems of Linear Algebra / Seymour
%             Lipschuts, Schaum's Outline Series, Mc-Graw-Hill inc.,
%             1973.
%
%             See also: inv, det, adj.
%

% Author: Ariel Tankus.
% Created: 14.11.98.

function cof_mat = cofactor(A)

[s1, s2] = size(A);
if (s1 ~= s2)
    error('cofactor defined for square matrices only.');
end

if (s1 == 3)
    % time optimization for 3x3 matrices
    cof_mat = [cross(A(:,2), A(:,3)), ...
        cross(A(:,3), A(:,1)), ...
        cross(A(:,1), A(:,2))];
    return;
end

cof_mat = zeros(s1, s2);

for i=1:s1
    for j=1:s2
        cof_mat(i,j) = (-1)^(i+j)*det(...
            [A(1:(i-1), 1:(j-1)),  A(1:(i-1), (j+1):s2);
             A((i+1):s1, 1:(j-1)), A((i+1):s1, (j+1):s2)]);
    end
end
