## Copyright (C) 1998 Ariel Tankus
## 
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## sph2cart    Convert spheric coordinates to cartesian representation.
##
##             [x, y, z] = sph2cart(az, el, r)
##             az - rad - azimuth. angle from the X axis to the projection
##                        of the vector on the [XY] plane.
##             el - rad - elevation. angle between the projection of the
##                        vector on the [XY] plane and the vector itself.
##             r  - norm of vector.
##
##             x - X coordinate of the vector.
##             y - Y coordinate of the vector.
##             z - Z coordinate of the vector.
##
##             If only one input/output argument exists, it is assumed a
##             vector of length 3, whose elements are the appropriate
##             coordinates.
##
##             See also: cart2sph, pol2cart, cart2pol.
##

## Author: Ariel Tankus. <arielt@math.tau.ac.il>
## Created: 10.11.98.
## Version: 1.1

function [x, y, z] = sph2cart(az, el, r)

  ## allow `r' to contain the whole vector
  if ((nargin == 1) & (prod(size(az)) == 3))
    el = az(2);
    r  = az(3);
    az = az(1);
  end

  x = r * cos(el) * cos(az);
  y = r * cos(el) * sin(az);
  z = r * sin(el);

  if (nargout <= 1)
    x = [x; y; z];
  end

endfunction
