## Copyright (C) 1998 Ariel Tankus
## 
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## expandPath  Search a file in a given search path.
##             Return the full path of the file, if found and readable.
##             Otherwise, return an empty string.
##
##             fullname = expandPath(filename, searchPath)
##             filename   - string - name of file to search.
##             searchPath - string array - each row should represent
##                              a directory in the search path
##                              (trailing blanks allowed).
##             fullname   - string - full name of file (i.e, with full path).
##
##             See also: fileExists.

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 14.4.98.
## Version: 1.0

function fullname = expandPath(filename, searchPath)

## handle home-relative path (i.e, '~')
if (filename(1) == '~')

    userHome = getenv('HOME');
    fullname = [userHome, filename(2:length(filename))];
    fullname = fileExists(fullname);
    return;

end

## handle filename already with full path
if (filename(1) == '/')

    fullname = fileExists(filename);
    return;

end

## if necessary, really search the path
for i = 1:size(searchPath, 1)

    fullname = [deblank(searchPath(i,:)), '/', filename];
    fullname = fileExists(fullname);
    if (fullname ~= '')
        return;
    end

end

endfunction
