## Copyright (C) 1998 Ariel Tankus
## 
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## matchstring    Find a string in an array of strings.  Return the
##                indices in the array where the matches appear.
##                The comparison disregards trailing blanks (in either the
##                string array or the query string).
##
##                indices = matchstring(stringArray, string)
##                stringArray - mxn - array of strings.
##                string      - 1xk - a string.
##                indices     - 1xl - (l < m) vector of indices of the
##                                    rows where `string' appears in
##                                    `stringArray'.
##
##                See also: findstr.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 29.8.98.
## Version: 1.0

function indices = matchstring(stringArray, string)

  indices = [];
  for i = 1:size(stringArray, 1)
    if (strcmp(deblank(stringArray(i,:)), deblank(string)))
      indices = [indices, i];
    end
  end

endfunction
