## Copyright (C) 1998 Ariel Tankus
## 
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## removeext     Removes extension specification from full file name.
##               Returns the base filename, and optionally the extension.
##
##               [base, ext] = removeext(fname)
##               fname - full file name.
##               base  - base file name (i.e, fname w/o extension.
##                       path may still exist).
##               ext   - (opt.) filename extension (w/o leading `.').
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 13.2.98.
## Version: 1.0

function [base, ext] = removeext(fname)

  places = findstr(fname, '.');

  if length(places) == 0
    ## no '/' found
    base = fname;
    if nargout >= 2, ext = ''; end
    return
  end

  places = places(length(places));    # last occurance

  if places ~= 1
    base = fname(1:(places-1));
  else
    base = '';
  end

  if nargout >= 2,
    ext = fname((places+1):length(fname));
  end

endfunction
